/*******************************************************************************
 * University of Illinois/NCSA
 * Open Source License
 *
 * Copyright (c) 2010 , NCSA.  All rights reserved.
 *
 * Developed by:
 * Cyberenvironments and Technologies (CET)
 * http://cet.ncsa.illinois.edu/
 *
 * National Center for Supercomputing Applications (NCSA)
 * http://www.ncsa.illinois.edu/
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal with the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of CET, University of Illinois/NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 *******************************************************************************/
package edu.uiuc.ncsa.cet.bean;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import edu.uiuc.ncsa.cet.bean.gis.LocationBean;

public class PersonBean extends CETBean implements Serializable
{
    /**
     * Used for serialization of object
     */
    private static final long  serialVersionUID = 1L;

    /**
     * Name of the person.
     */
    private String             name             = "";                           //$NON-NLS-1$

    /**
     * email of the person.
     */
    private String             email            = "";                           //$NON-NLS-1$

    /**
     * a person can be associated with set of locations. e.g. home address,
     * office address or some other location.
     */
    private List<LocationBean> locations        = new ArrayList<LocationBean>();

    /**
     * photograph or portrait of person or any other blob can be associated with
     * a person
     */
    private BlobBean           blob             = null;

    /**
     * set of organizations associated with person.
     */
    // private Set<OrganizationBean> organizations = new
    // HashSet<OrganizationBean>();
    /**
     * person can be member of set of groups
     */
    // private Set<GroupBean> groups = new HashSet<GroupBean>();

    /**
     * Create a definition of a anonymous user
     */
    public PersonBean()
    {
    }

    /**
     * Sets the name of the person.
     * 
     * @param name
     *            the name of the person
     */
    public void setName( String name )
    {
        this.name = name;
    }

    /**
     * Gets the name of the person.
     * 
     * @return the name of the person.
     */
    public String getName()
    {
        return name;
    }

    /**
     * Sets the label to be the same as the name if the label is missing.
     */
    @Override
    public String getLabel()
    {
        if ( label == null ) {
            label = getName();
        }
        return label;
    }

    /**
     * Sets the email of the person.
     * 
     * @param email
     *            the email of the person
     */
    public void setEmail( String email )
    {
        this.email = email;
    }

    /**
     * Gets the email of the person.
     * 
     * @return the email of the person.
     */
    public String getEmail()
    {
        return email;
    }

    public List<LocationBean> getLocations()
    {
        return locations;
    }

    public void setLocations( List<LocationBean> locations )
    {
        this.locations.clear();
        if ( locations != null ) {
            this.locations = locations;
        }
    }

    public void addLocation( LocationBean location )
    {
        this.locations.add( location );
    }

    public void removeLocation( LocationBean location )
    {
        this.locations.remove( location );
    }

    public BlobBean getBlob()
    {
        return blob;
    }

    public void setBlob( BlobBean blob )
    {
        this.blob = blob;
    }

}